@@ -31,7 +31,7 @@ public:
     const QList<KCalendarCore::Attendee::PartStat> &blockedStatusList() const;
 
 protected:
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    [[nodiscard]] bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
 private:
     //@cond PRIVATE
